@@ -120,17 +120,19 @@ class BasicTests(unittest.TestCase):
         self.assertTrue("name" in g.vertex_attributes())
         self.assertEqual(g.vs["name"], [None, "foo"])
 
-        vertex = g.add_vertex(3)
+        self.assertRaises(TypeError, g.add_vertex, 3)
+
+        vertex = g.add_vertex("3")
         self.assertTrue(g.vcount() == 3 and g.ecount() == 0)
         self.assertEqual(2, vertex.index)
         self.assertTrue("name" in g.vertex_attributes())
-        self.assertEqual(g.vs["name"], [None, "foo", 3])
+        self.assertEqual(g.vs["name"], [None, "foo", "3"])
 
         vertex = g.add_vertex(name="bar")
         self.assertTrue(g.vcount() == 4 and g.ecount() == 0)
         self.assertEqual(3, vertex.index)
         self.assertTrue("name" in g.vertex_attributes())
-        self.assertEqual(g.vs["name"], [None, "foo", 3, "bar"])
+        self.assertEqual(g.vs["name"], [None, "foo", "3", "bar"])
 
         vertex = g.add_vertex(name="frob", spam="cheese", ham=42)
         self.assertTrue(g.vcount() == 5 and g.ecount() == 0)
@@ -943,15 +945,15 @@ class ReferenceCountTests(unittest.TestCase):
 
 
 def suite():
-    basic_suite = unittest.makeSuite(BasicTests)
-    datatype_suite = unittest.makeSuite(DatatypeTests)
-    graph_dict_list_suite = unittest.makeSuite(GraphDictListTests)
-    graph_tuple_list_suite = unittest.makeSuite(GraphTupleListTests)
-    graph_list_dict_suite = unittest.makeSuite(GraphListDictTests)
-    graph_dict_dict_suite = unittest.makeSuite(GraphDictDictTests)
-    degree_sequence_suite = unittest.makeSuite(DegreeSequenceTests)
-    inheritance_suite = unittest.makeSuite(InheritanceTests)
-    refcount_suite = unittest.makeSuite(ReferenceCountTests)
+    basic_suite = unittest.defaultTestLoader.loadTestsFromTestCase(BasicTests)
+    datatype_suite = unittest.defaultTestLoader.loadTestsFromTestCase(DatatypeTests)
+    graph_dict_list_suite = unittest.defaultTestLoader.loadTestsFromTestCase(GraphDictListTests)
+    graph_tuple_list_suite = unittest.defaultTestLoader.loadTestsFromTestCase(GraphTupleListTests)
+    graph_list_dict_suite = unittest.defaultTestLoader.loadTestsFromTestCase(GraphListDictTests)
+    graph_dict_dict_suite = unittest.defaultTestLoader.loadTestsFromTestCase(GraphDictDictTests)
+    degree_sequence_suite = unittest.defaultTestLoader.loadTestsFromTestCase(DegreeSequenceTests)
+    inheritance_suite = unittest.defaultTestLoader.loadTestsFromTestCase(InheritanceTests)
+    refcount_suite = unittest.defaultTestLoader.loadTestsFromTestCase(ReferenceCountTests)
     return unittest.TestSuite(
         [
             basic_suite,
