@@ -787,6 +787,14 @@ class PathTests(unittest.TestCase):
             == [row[2:4] for row in expected]
         )
 
+    def testGetShortestPath(self):
+        g = Graph(4, [(0, 1), (0, 2), (1, 3), (3, 2), (2, 1)], directed=True)
+        self.assertEqual([0, 1, 3], g.get_shortest_path(0, 3))
+        self.assertEqual([0, 1, 3], g.get_shortest_path(0, 3, output="vpath"))
+        self.assertEqual([0, 2], g.get_shortest_path(0, 3, output="epath"))
+        self.assertRaises(ValueError, g.get_shortest_path, 0, 3, output="x")
+        self.assertRaises(TypeError, g.get_shortest_path, 0)
+
     def testGetShortestPaths(self):
         g = Graph(4, [(0, 1), (0, 2), (1, 3), (3, 2), (2, 1)], directed=True)
         sps = g.get_shortest_paths(0)
@@ -860,21 +868,21 @@ class PathTests(unittest.TestCase):
 
     def testGetKShortestPaths(self):
         g = Graph(4, [(0, 1), (1, 2), (1, 3), (2, 4), (3, 4), (4, 5)], directed=True)
-    
+
         sps = sorted(g.get_k_shortest_paths(0, 0))
         expected = [[0]]
         self.assertEqual(expected, sps)
-    
+
         sps = sorted(g.get_k_shortest_paths(0, 5, 2))
         expected = [[0, 1, 2, 4, 5], [0, 1, 3, 4, 5]]
         self.assertEqual(expected, sps)
-    
+
         sps = sorted(g.get_k_shortest_paths(1, 4, 2))
         expected = [[1, 2, 4], [1, 3, 4]]
         self.assertEqual(expected, sps)
-    
+
         g = Graph.Lattice([5, 5], circular=False)
-    
+
         sps = sorted(g.get_k_shortest_paths(0, 12, 6))
         expected = [
             [0, 1, 2, 7, 12],
@@ -885,7 +893,7 @@ class PathTests(unittest.TestCase):
             [0, 5, 10, 11, 12],
         ]
         self.assertEqual(expected, sps)
-    
+
         g = Graph.Lattice([100, 100], circular=False)
         sps = sorted(g.get_k_shortest_paths(0, 202, 6))
         expected = [
@@ -897,12 +905,12 @@ class PathTests(unittest.TestCase):
             [0, 100, 200, 201, 202],
         ]
         self.assertEqual(expected, sps)
-    
+
         g = Graph([(0, 1), (1, 2), (0, 2)])
         g.es["weight"] = [0.5, 0.5, 1]
         sps = sorted(g.get_k_shortest_paths(0, 2, 2, weights="weight"))
         self.assertEqual(sorted([[0, 2], [0, 1, 2]]), sorted(sps))
-    
+
     def testGetAllSimplePaths(self):
         g = Graph.Ring(20)
         sps = sorted(g.get_all_simple_paths(0, 10))
@@ -957,6 +965,22 @@ class PathTests(unittest.TestCase):
         h = g.path_length_hist(False)
         self.assertTrue(h.unconnected == 20)
 
+    def testGetShortestPathsAStar(self):
+        n = 4
+        g = Graph.Lattice((n, n), circular=False)
+        xs, ys = list(range(n)) * n, sum(([i] * n for i in range(n)), [])
+        g.vs["coord"] = list(zip(xs, ys))
+
+        def heuristics(graph, u, v):
+            ux, uy = graph.vs[u]["coord"]
+            vx, vy = graph.vs[v]["coord"]
+            return ((ux - vx) ** 2 + (uy - vy) ** 2) ** 0.5
+
+        self.assertEqual(
+            [0, 1, 5, 6, 10, 11],
+            g.get_shortest_path_astar(0, 11, heuristics)
+        )
+
 
 class DominatorTests(unittest.TestCase):
     def compareDomTrees(self, alist, blist):
